==> mupad-1.4.2.tgz: mupad/share/mmg/include/kernel/MFO_fileop.h <==
/* $Date: 1997/12/19 09:06:51 $  $Author: kg $  $Revision: 1.8 $ */

/**************************************************************************/
/* FILE:             MFO_fileop.h                                         */
/* Autor:            Klaus Gottheil                                       */
/* Erstellt:         30/11/92                                             */
/* Letzte Aenderung: 15/06/94                                             */
/**************************************************************************/

#ifndef __MFO_fileop__
#define __MFO_fileop__


#ifdef MACINTOSH
    /* Dialog bei Ueberschreiben eines Files oeffnen, falls auf
     * interaktiver Ebene. */
#   define MFO_OVERWRITE_DIALOG (GLOBAL_READ(MUPV_REAL_PROC_DEPTH) == 0L)
#else
#   define MFO_OVERWRITE_DIALOG 0L
#endif

#ifdef USE_PRAGMA
#pragma GLOBAL_PRAGMA( MUPbool, MFOV_QUIET )
#endif
GLOBAL_DECL( MUPbool, MFOV_QUIET );

#ifdef USE_PRAGMA
#pragma GLOBAL_PRAGMA( long, MFOV_FREAD_COUNT )
#endif
GLOBAL_DECL( long, MFOV_FREAD_COUNT );

#ifdef USE_PRAGMA
#pragma GLOBAL_PRAGMA( MUPbool, MFOV_INTERUPTED )
#endif
GLOBAL_DECL( MUPbool, MFOV_INTERUPTED );

/**************************************************************************/
/* Headerfile fuer die File-Operationen					  */
/**************************************************************************/

void      MFO_init(VOID);
void      MFO_exit(VOID);
void      MFO_reset(VOID);
MUPbool	  MFO_read(char *);

S_Pointer MFO_eval_fclose(S_Pointer s, long prev_func,
			long eval_type, S_Pointer exec);
S_Pointer MFO_eval_fopen(S_Pointer s, long prev_func,
			long eval_type, S_Pointer exec);
S_Pointer MFO_eval_fread(S_Pointer s, long prev_func,
			long eval_type, S_Pointer exec);
S_Pointer MFO_eval_write(S_Pointer s, long prev_func,
			long eval_type, S_Pointer exec);
S_Pointer MFO_eval_fprint(S_Pointer s, long prev_func,
			long eval_type, S_Pointer exec);
S_Pointer MFO_eval_finput(S_Pointer s, long prev_func,
			long eval_type, S_Pointer exec);
S_Pointer MFO_eval_ftextinput(S_Pointer s, long prev_func,
			long eval_type, S_Pointer exec);
S_Pointer MFO_eval_protocol(S_Pointer s, long prev_func,
			long eval_type, S_Pointer exec);

#endif /* __MFO_fileop__ */

==> mupad-2.0.0.tgz: mupad/share/mmg/include/kernel/MFO_fileop.h <==
/* $Date: 2000/04/11 14:15:22 $  $Author: tonner $  $Revision: 1.14 $ */

/**************************************************************************/
/* FILE:             MFO_fileop.h                                         */
/* Autor:            Klaus Gottheil                                       */
/* Erstellt:         30/11/92                                             */
/* Letzte Aenderung: 15/06/94                                             */
/**************************************************************************/

#ifndef __MFO_fileop__
#define __MFO_fileop__


#ifdef MACINTOSH
    /* Dialog bei Ueberschreiben eines Files oeffnen, falls auf
     * interaktiver Ebene. */
#   define MFO_OVERWRITE_DIALOG (GLOBAL_READ(MUPV_REAL_PROC_DEPTH) == 0)
#else
#   define MFO_OVERWRITE_DIALOG 0
#endif

GLOBAL_DECL( bool, MFOV_QUIET );
GLOBAL_DECL( long, MFOV_FREAD_COUNT );

MTR_DECL_LITERAL(MSTR_Plain)
MTR_DECL_LITERAL(MSTR_InputOnly)
MTR_DECL_LITERAL(MSTR_Quiet)
MTR_DECL_LITERAL(MSTR_Unquoted)
MTR_DECL_LITERAL(MSTR_NoNL)
MTR_DECL_LITERAL(MSTR_Append)
MTR_DECL_LITERAL(MSTR_Write)
MTR_DECL_LITERAL(MSTR_Text)
MTR_DECL_LITERAL(MSTR_Bin)

/**************************************************************************/
/* Headerfile fuer die File-Operationen					  */
/**************************************************************************/

void      MFO_init();
void      MFO_exit();
/* Use only when you really know what yo do !!!!
   Read function header for more details.          */ 
void      MFO_reset(bool close_prot=false);
S_Pointer MFO_save_descr();
void      MFO_set_save_descr(S_Pointer s);

bool	  MFO_read(char *fname, bool plain, bool in_eval);

S_Pointer MFO_eval_fclose(S_Pointer s, long prev_func,
			long eval_type, S_Pointer exec);
S_Pointer MFO_eval_fopen(S_Pointer s, long prev_func,
			long eval_type, S_Pointer exec);
S_Pointer MFO_eval_fread(S_Pointer s, long prev_func,
			long eval_type, S_Pointer exec);
S_Pointer MFO_eval_write(S_Pointer s, long prev_func,
			long eval_type, S_Pointer exec);
S_Pointer MFO_eval_fprint(S_Pointer s, long prev_func,
			long eval_type, S_Pointer exec);
S_Pointer MFO_eval_finput(S_Pointer s, long prev_func,
			long eval_type, S_Pointer exec);
S_Pointer MFO_eval_ftextinput(S_Pointer s, long prev_func,
			long eval_type, S_Pointer exec);
S_Pointer MFO_eval_protocol(S_Pointer s, long prev_func,
			long eval_type, S_Pointer exec);

#endif /* __MFO_fileop__ */
